/*
 * \brief  General Azure SDK utility functions
 * \author Timo Nicolai
 * \date   2023-02-23
 */

/*
 * Copyright (C) 2023 gapfruit AG
 */

#pragma once

/* Genode includes */
#include <util/string.h>

/* Azure includes */
extern "C" {

#include <azure/az_iot.h>

}


namespace Azure {

	inline ::az_span to_span(char const *str)
	{
		return ::az_span_create_from_str(const_cast<char *>(str));
	}

	template<Genode::size_t CAPACITY>
	::az_span to_span(Genode::String<CAPACITY> const &str)
	{
		return to_span(str.string());
	}

	/* `T` should be `Genode::String<CAPACITY>` */
	template<typename T>
	T from_span(::az_span span)
	{
		char buf[T::size()];
		::az_span_to_str(buf, sizeof(buf), span);
		return T { buf };
	}

	template<typename T>
	bool span_equal(::az_span span, T const &str)
	{
		return ::az_span_is_content_equal(span, to_span(str));
	}
}
