/*
 * \brief  Config handling
 * \author Timo Nicolai
 * \date   2023-03-06
 */

/*
 * Copyright (C) 2023 gapfruit AG
 */

#pragma once

/* Genode includes */
#include <base/exception.h>
#include <base/log.h>
#include <util/xml_node.h>

namespace Azure_iot_client {
	class Config;
}


class Azure_iot_client::Config
{
	public:

		struct Invalid_config : Genode::Exception { };

	private:

		Genode::Xml_node const _xml;

	public:

		explicit Config(Genode::Xml_node const &xml) : _xml { xml } { }

		template<typename T>
		T get(char const *key) const
		{
			if (!_xml.has_attribute(key)) {
				Genode::error("invalid config, missing '", key, "'");
				throw Invalid_config { };
			}

			T value;
			_xml.attribute(key).value(value);

			return value;
		}
};
